Welcome to stdatamodels's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   asdf_in_fits.rst

JWST
====

.. toctree::
   :maxdepth: 2

   jwst/datamodels/index.rst
   jwst/transforms/index.rst

API
===

.. toctree::
   :maxdepth: 1

   api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
